@@ -1,4 +1,4 @@
-//$Id: button.h,v 1.23 2003/06/30 14:07:57 cactus Exp $ -*- c++ -*-
+//$Id: button.h,v 1.25 2004/01/18 10:55:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include "widget.h"
 #include "auto-resizeable.h"
 #include "textual.h"
+#include "graphical.h"
 
 namespace Guikachu
 {
@@ -30,7 +31,8 @@ namespace Guikachu
 	class Button: public Widget,
 		      public AutoWidth,
 		      public AutoHeight,
-		      public Textual
+		      public Textual,
+                      public Graphical
 	{
 	public:
 	    Button (Resources::Form *owner, const std::string &id, serial_t serial);
@@ -45,11 +47,11 @@ namespace Guikachu
 		FRAME_BOLD
 	    };
 
-	    Property<FrameType> frame;
+	    Property<FrameType>     frame;
 
-	    Property<bool>      usable;
-	    Property<bool>      repeat;
-	    Property<bool>      anchor_right;
+	    Property<bool>          usable;
+	    Property<bool>          repeat;
+	    Property<bool>          anchor_right;
 
 	protected:
 	    int get_auto_width  () const ;
