@@ -1,6 +1,6 @@
-//$Id: text-field-prop.cc,v 1.12 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
+//$Id: text-field-prop.cc,v 1.14 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,7 +21,6 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#include "widget-prop.h"
 #include "resizeable-prop.h"
 #include "auto-resizeable-prop.h"
 
@@ -35,7 +34,8 @@
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
-TextFieldProperties::TextFieldProperties (TextField *res)
+TextFieldProperties::TextFieldProperties (TextField *res):
+    WidgetProperties (res)
 {
     using namespace SigC;
     using WidgetOps::PropChangeOpFactory;
@@ -44,7 +44,7 @@ TextFieldProperties::TextFieldProperties (TextField *res)
     Gtk::Widget *control;
     
     /* Resource ID */
-    WidgetProperties::add_general_controls (res, *proptable);
+    add_general_controls (*proptable);
 
     /* Usable */
     control = new GUI::PropertyEditors::ToggleButton (
@@ -133,7 +133,7 @@ TextFieldProperties::TextFieldProperties (TextField *res)
     proptable->add_separator ();
 
     /* Position */
-    WidgetProperties::add_position_controls (res, *proptable);
+    add_position_controls (*proptable);
 
     /* Size */
     ResizeableProperties::add_width_controls (res, *proptable);
