@@ -1,6 +1,6 @@
-//$Id: text-field.cc,v 1.17 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
+//$Id: text-field.cc,v 1.20 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -17,7 +17,6 @@
  */
 
 #include "text-field.h"
-#include "text-field-canvas.h"
 
 #include "form-editor.h"
 
@@ -25,11 +24,11 @@ using Guikachu::Widgets::TextField;
 using namespace Guikachu::GUI::FormEditor;
 
 TextField::TextField (Resources::Form   *owner,
-		      const std::string &id):
-    Widget (owner, id),
+		      const std::string &id,
+		      serial_t           serial):
+    Widget (owner, id, serial),
     ResizeableWidget (changed),
     AutoHeight (changed),
-    editor (0),
     
     usable (changed, true),
 
@@ -48,25 +47,6 @@ TextField::TextField (Resources::Form   *owner,
     width = 30;
 }
 
-TextField::~TextField ()
-{
-    if (editor)
-	delete editor;
-}
-
-Gtk::Widget* TextField::create_editor ()
-{
-    if (!editor)
-	editor = new TextFieldProperties (this);
-    
-    return editor->get_editor ();
-}
-
-WidgetCanvasItem* TextField::create_canvas_item (Gnome::CanvasGroup *parent_group)
-{
-    return new TextFieldCanvasItem (this, parent_group);
-}
-
 int TextField::get_height () const
 {
     int min_height = get_auto_height ();
