@@ -1,6 +1,6 @@
-//$Id: form-win.h,v 1.36 2003/01/28 19:09:56 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.38 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -19,17 +19,12 @@
 #ifndef GUIKACHU_FORM_WIN_H
 #define GUIKACHU_FORM_WIN_H
 
-namespace Guikachu
-{
-    namespace GUI
-    {
-	class FormWindow;
-    }
-}
-
 #include "form-res.h"
+#include "resource-win.h"
+
 #include "form-editor/form.h"
 #include "form-editor/form-canvas.h"
+#include "form-editor/widget-canvas.h"
 #include "form-editor/widget.h"
 
 #include <gtk--/window.h>
@@ -50,7 +45,8 @@ namespace Guikachu
 	    class CanvasSelectionWrapper;
 	}
 	
-	class FormWindow: public SigC::Object
+	class FormWindow: public ResourceWindow,
+			  public SigC::Object
 	{
 	    Resources::Form *res;
 	    
@@ -113,6 +109,8 @@ namespace Guikachu
 
 	    void widget_remove_cb (Widget *widget);
 
+	    FormEditor::WidgetCanvasItem * get_canvas_item (Widget *widget);
+	    
 	    // Layouting
 	    void align_left   ();
 	    void align_right  ();
@@ -156,7 +154,7 @@ namespace Guikachu
 	    void widget_drag_motion_cb (int dx, int dy);
 	    void widget_drag_end_cb    (int dx, int dy);
 	};
-    };
-};
+    }
+}
 
 #endif /* !GUIKACHU_FORM_WIN_H */
