@@ -1,4 +1,4 @@
-//$Id: io.cc,v 1.3 2004/01/26 22:08:38 cactus Exp $ -*- c++ -*-
+//$Id: io.cc,v 1.4 2004/03/20 23:46:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,6 +18,13 @@
 
 #include "io/io.h"
 
+#include "io/xml-loader.h"
+#include "io/xml-saver.h"
+#include "io/rcp-loader.h"
+#include "io/rcp-save.h"
+
+#include <libgnomevfs/gnome-vfs-mime.h>
+
 using namespace Guikachu;
 
 std::string IO::create_canonical_uri (const std::string &filename)
@@ -112,3 +119,71 @@ IO::IOResult IO::save_uri (const std::string &uri, const char *data, GnomeVFSFil
 
     return res;
 }
+
+std::string IO::get_mime_type (const std::string &uri)
+{
+#if 0
+    GnomeVFSURI *vfs_uri = gnome_vfs_uri_new (uri.c_str ());
+    if (!vfs_uri)
+	return "";
+    
+    std::string ret = gnome_vfs_get_mime_type (vfs_uri);
+    gnome_vfs_uri_unref (vfs_uri);
+    return ret;
+#else
+    return gnome_vfs_mime_type_from_name ("foo.guikachu");
+#endif
+}
+
+IO::IOFactory * IO::IOFactory::instance_ = 0;
+
+namespace
+{
+    template<class T>
+    IO::Loader * loader_factory ()
+    {
+	return new T;
+    }
+
+    template<class T>
+    IO::Saver * saver_factory ()
+    {
+	return new T;
+    }
+    
+} // anonymous namespace
+
+IO::IOFactory::IOFactory ()
+{
+    loader_map["application/x-guikachu"] = loader_factory<IO::XMLLoader>;
+    loader_map["text/x-rcp"] = loader_factory<IO::RCPLoader>;
+
+    saver_map["application/x-guikachu"] = saver_factory<IO::XMLSaver>;
+    saver_map["text/x-rcp"] = saver_factory<IO::RCPSaver>;
+}
+
+IO::IOFactory * IO::IOFactory::instance ()
+{
+    if (!instance_)
+	instance_ = new IOFactory;
+	
+    return instance_;
+}
+
+IO::Loader * IO::IOFactory::create_loader (const std::string &mime_type) const
+{
+    loader_map_t::const_iterator found = loader_map.find (mime_type);
+    if (found == loader_map.end ())
+	return 0;
+
+    return found->second ();
+}
+
+IO::Saver * IO::IOFactory::create_saver (const std::string &mime_type) const
+{
+    saver_map_t::const_iterator found = saver_map.find (mime_type);
+    if (found == saver_map.end ())
+	return 0;
+
+    return found->second ();
+}
