@@ -1,4 +1,4 @@
-//$Id: widget-io.cc,v 1.1 2002/08/01 18:06:06 cactus Exp $ -*- c++ -*-
+//$Id: widget-io.cc,v 1.2 2003/12/18 21:04:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,7 @@
 #include "io/xml-saver.h"
 #include "io/xml-loader.h"
 
+#include "io/xml/widget-formbitmap.h"
 #include "io/xml/widget-button.h"
 #include "io/xml/widget-checkbox.h"
 #include "io/xml/widget-gadget.h"
@@ -73,6 +74,7 @@ CREATE_WIDGET_IO_VISITOR(PopupTrigger);
 CREATE_WIDGET_IO_VISITOR(ScrollBar);
 CREATE_WIDGET_IO_VISITOR(TextField);
 CREATE_WIDGET_IO_VISITOR(Table);
+CREATE_WIDGET_IO_VISITOR(FormBitmap);
 CREATE_WIDGET_IO_VISITOR(Gadget);
 
 } // namespace XML
